import unittest
import pandas as pd
from sklearn.metrics import accuracy_score

from rapidoml import AutoML
from rapidoml.datasets import load_dataset, preprocess_data


class TestRapidoML(unittest.TestCase):

    def test_load_dataset(self):
        X, y = load_dataset('iris.csv', target_column='species')
        self.assertIsInstance(X, pd.DataFrame)
        self.assertIsInstance(y, pd.Series)

    def test_automl_iris(self):
        X, y = load_dataset('iris.csv', target_column='species')
        X_train, X_test, y_train, y_test = preprocess_data(X, y, test_size=0.3)

        automl = AutoML()
        automl.train(X_train, y_train, model='XGBClassifier')
        y_pred = automl.predict(X_test)
        accuracy = accuracy_score(y_test, y_pred)

        self.assertGreater(accuracy, 0.8)



import unittest
import pandas as pd
from rapidoml.datasets import sample_datasets
from rapidoml.preprocessing import preprocess_data
from sklearn.datasets import load_iris, load_digits

class TestSampleDatasets(unittest.TestCase):
    def test_iris_dataset(self):
        X_train, X_test, y_train, y_test = sample_datasets('iris')
        iris = load_iris()
        df_train = pd.DataFrame(X_train, columns=iris.feature_names)
        df_test = pd.DataFrame(X_test, columns=iris.feature_names)
        df_train['species'] = y_train
        df_test['species'] = y_test

        df_processed = preprocess_data(df_train, categorical_columns=['species'], numerical_columns=iris.feature_names)
        self.assertEqual(df_processed['species'].nunique(), 3)

    def test_digits_dataset(self):
        X_train, X_test, y_train, y_test = sample_datasets('digits')
        digits = load_digits()
        df_train = pd.DataFrame(X_train, columns=[f"pixel_{i}" for i in range(X_train.shape[1])])
        df_test = pd.DataFrame(X_test, columns=[f"pixel_{i}" for i in range(X_train.shape[1])])
        df_train['target'] = y_train
        df_test['target'] = y_test

        df_processed = preprocess_data(df_train, numerical_columns=[f"pixel_{i}" for i in range(X_train.shape[1])])
        self.assertAlmostEqual(df_processed.mean().sum(), 0.0, delta=1e-6)


if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="rapidoml",
    version="0.1.3",
    packages=find_packages(),
    install_requires=[
        "numpy",
        "scikit-learn",
        "tensorflow",
        "keras",
        "xgboost",
        "lightgbm",
        "catboost"
    ],
    author='Fabio Carvalho',
    author_email='hipnologo@gmail.com',
    license='Apache License, Version 2.0',
    description="RapidoML is a simple Automated Machine Learning (AutoML) library",
    url="https://github.com/hipnologo/rapidoml",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
)
